@@ -27,7 +27,7 @@ def test_cve_json():
 
 def test_bulk_search(test_app_info, test_pkg_list):
     data = NpmSource().bulk_search(test_app_info, test_pkg_list)
-    assert len(data) == 7
+    assert len(data) > 7
     assert data[0].id == "CVE-2017-16042"
 
 
