@@ -12,7 +12,15 @@ import logging
 import os
 import re
 
-import orjson
+try:
+    import orjson
+
+    ORJSON_AVAILABLE = True
+except ImportError:
+    import json
+
+    ORJSON_AVAILABLE = False
+
 import requests
 
 from vdb.lib import config as config
@@ -27,10 +35,11 @@ LOG = logging.getLogger(__name__)
 api_token = os.environ.get("GITHUB_TOKEN")
 headers = {"Authorization": "token %s" % api_token}
 
+json_lib = orjson if ORJSON_AVAILABLE else json
+
 
 def get_query(type="recent"):
-    """
-    """
+    """"""
     extra_args = ""
     if type == "recent" or not type:
         extra_args = "first: 100"
@@ -85,12 +94,10 @@ def get_query(type="recent"):
 
 
 class GitHubSource(NvdSource):
-    """GitHub CVE source
-    """
+    """GitHub CVE source"""
 
     def download_all(self, local_store=True):
-        """Download all historic cve data
-        """
+        """Download all historic cve data"""
         data_list = []
         lastId = None
         for y in range(0, int(config.gha_pages_count)):
@@ -104,16 +111,14 @@ class GitHubSource(NvdSource):
         return data_list
 
     def download_recent(self, local_store=True):
-        """Method which downloads the recent CVE
-        """
+        """Method which downloads the recent CVE"""
         data, page_info = self.fetch("recent")
         if data and local_store:
             self.store(data)
         return data
 
     def fetch(self, type):
-        """Private method to fetch the advisory data via GraphQL api
-        """
+        """Private method to fetch the advisory data via GraphQL api"""
         LOG.debug(
             "Download GitHub advisory from {} with cursor {}".format(
                 config.gha_url, type
@@ -171,8 +176,7 @@ class GitHubSource(NvdSource):
         )
 
     def convert(self, cve_data):
-        """Convert the GitHub advisory data into Vulnerability objects
-        """
+        """Convert the GitHub advisory data into Vulnerability objects"""
         ret_data = []
         if cve_data.get("errors"):
             return ret_data, None
@@ -195,6 +199,9 @@ class GitHubSource(NvdSource):
             if not cve_id:
                 cve_id = cve["ghsaId"]
                 assigner = "@github"
+            references = json_lib.dumps(references)
+            if isinstance(references, bytes):
+                references = references.decode("utf-8", "ignore")
             for p in cve["vulnerabilities"]["nodes"]:
                 vendor = p["package"]["ecosystem"]
                 product = p["package"]["name"]
@@ -234,11 +241,12 @@ class GitHubSource(NvdSource):
             """.format(
                     cve.get("summary"), cve.get("description")
                 )
+
                 tdata = config.CVE_TPL % dict(
                     cve_id=cve_id,
                     cwe_id="UNKNOWN",
                     assigner=assigner,
-                    references=orjson.dumps(references).decode("utf-8"),
+                    references=references,
                     description="",
                     vectorString=vectorString,
                     vendor=vendor.lower(),
@@ -260,7 +268,7 @@ class GitHubSource(NvdSource):
                     lastModifiedDate=cve["updatedAt"],
                 )
                 try:
-                    tdata_json = orjson.loads(tdata)
+                    tdata_json = json_lib.loads(tdata)
                     vuln = NvdSource.convert_vuln(tdata_json)
                     vuln.description = description
                     ret_data.append(vuln)
